@@ -330,7 +330,7 @@ function os.match(pattern, mode, callback)
     end
 
     -- translate path and remove some repeat separators
-    pattern = path.translate(pattern:gsub("|.*$", ""))
+    pattern = path.translate((pattern:gsub("|.*$", "")))
 
     -- translate mode
     if type(mode) == "string" then
@@ -804,10 +804,10 @@ function os.execv(program, argv, opt)
         local file = io.open(filename, 'r')
         for line in file:lines() do
             if line and line:startswith("#!") then
-                -- we cannot run `/bin/sh` directly on msys2/cygwin
+                -- we cannot run `/bin/sh` directly on windows
                 -- because `/bin/sh` is not real file path, maybe we need to convert it.
-                local subhost = os.subhost()
-                if subhost == "msys" or subhost == "cygwin" then
+                local host = os.host()
+                if host == "windows" then
                     filename = "sh"
                     argv = table.join(shellfile, argv)
                 else
@@ -830,20 +830,36 @@ function os.execv(program, argv, opt)
 
     -- uses the given environments?
     local envs = nil
-    if opt.envs then
+    local setenvs = opt.setenvs or opt.envs
+    local addenvs = opt.addenvs
+    if setenvs or addenvs then
         local envars = os.getenvs()
-        for k, v in pairs(opt.envs) do
-            if type(v) == "table" then
-                v = path.joinenv(v)
+        if setenvs then
+            for k, v in pairs(setenvs) do
+                if type(v) == "table" then
+                    v = path.joinenv(v)
+                end
+                envars[k] = v
             end
+        end
+        if addenvs then
+            for k, v in pairs(addenvs) do
+                if type(v) == "table" then
+                    v = path.joinenv(v)
+                end
+                local o = envars[k]
+                if o then
+                    v = v .. path.envsep() .. o
+                end
+                envars[k] = v
+            end
+        end
+        envs = {}
+        for k, v in pairs(envars) do
             -- we try to fix too long value before running process
             if type(v) == "string" and #v > 4096 and os.host() == "windows" then
                 v = os._deduplicate_pathenv(v)
             end
-            envars[k] = v
-        end
-        envs = {}
-        for k, v in pairs(envars) do
             table.insert(envs, k .. '=' .. v)
         end
     end
@@ -860,6 +876,7 @@ function os.execv(program, argv, opt)
 
     -- open command
     local ok = -1
+    local errors
     local proc = process.openv(filename, argv or {}, openopt)
     if proc ~= nil then
 
@@ -871,9 +888,16 @@ function os.execv(program, argv, opt)
 
         -- wait process
         if not opt.detach then
-            local waitok, status = proc:wait(-1)
+            local waitok, status = proc:wait(opt.timeout or -1)
             if waitok > 0 then
                 ok = status
+            elseif waitok == 0 and opt.timeout then
+                proc:kill()
+                waitok, status = proc:wait(-1)
+                if waitok > 0 then
+                    ok = status
+                end
+                errors = "wait process timeout"
             end
         else
             ok = 0
@@ -885,7 +909,7 @@ function os.execv(program, argv, opt)
         -- cannot execute process
         return nil, os.strerror()
     end
-    return ok
+    return ok, errors
 end
 
 -- run command and return output and error data
