@@ -40,6 +40,8 @@ function policy.policies()
             ["check.auto_map_flags"]              = {description = "Enable map gcc flags to the current compiler and linker automatically.", default = true, type = "boolean"},
             -- We will check the compatibility of target and package licenses
             ["check.target_package_licenses"]     = {description = "Enable check the compatibility of target and package licenses.", default = true, type = "boolean"},
+            -- Provide a way to block all targets build that depends on self
+            ["build.fence"]                       = {description = "Block all targets build that depends on self.", default = false, type = "boolean"},
             -- We can compile the source files for each target in parallel
             ["build.across_targets_in_parallel"]  = {description = "Enable compile the source files for each target in parallel.", default = true, type = "boolean"},
             -- Merge archive intead of linking for all dependent targets
@@ -48,8 +50,10 @@ function policy.policies()
             ["build.ccache"]                      = {description = "Enable C/C++ build cache.", type = "boolean"},
             -- Use global storage if build.ccache is enabled
             ["build.ccache.global_storage"]       = {description = "Use global storge if build.ccache is enabled.", type = "boolean"},
-            -- Enable build warning output, it's disabled by default and we need `xmake -w/-vD` to look at it.
-            ["build.warning"]                     = {description = "Enable build warning output.", type = "boolean"},
+            -- Always update configfiles when building
+            ["build.always_update_configfiles"]   = {description = "Always update configfiles when building.", type = "boolean"},
+            -- Enable build warning output, it's enabled by default.
+            ["build.warning"]                     = {description = "Enable build warning output.", default = true, type = "boolean"},
             -- Enable LTO linker-time optimization for c/c++ building.
             ["build.optimization.lto"]            = {description = "Enable LTO linker-time optimization for c/c++ building.", type = "boolean"},
             -- Enable address sanitizer for c/c++ building.
@@ -64,8 +68,12 @@ function policy.policies()
             ["build.sanitizer.undefined"]         = {description = "Enable undefined sanitizer for c/c++ building.", type = "boolean"},
             -- Enable C++ modules for C++ building, even if no .mpp is involved in the compilation
             ["build.c++.modules"]                 = {description = "Enable C++ modules for C++ building.", type = "boolean"},
-            -- Enable clang std modulemap
-            ["build.c++.clang.stdmodules"]        = {description = "Enable clang std modulemap.", default = false, type = "boolean"},
+            -- Enable std module
+            ["build.c++.modules.std"]             = {description = "Enable std modules.", default = true, type = "boolean"},
+            -- Try to reuse compiled module bmi file if targets flags permit it
+            ["build.c++.modules.tryreuse"]        = {description = "Try to reuse compiled module if possible.", default = true, type = "boolean"},
+            -- Enable module taking defines acbount for bmi reuse discrimination
+            ["build.c++.modules.tryreuse.discriminate_on_defines"] = {description = "Enable defines module reuse discrimination.", default = false, type = "boolean"},
             -- Force C++ modules fallback dependency scanner for clang
             ["build.c++.clang.fallbackscanner"]   = {description = "Force clang fallback module dependency scanner.", default = false, type = "boolean"},
             -- Force C++ modules fallback dependency scanner for msvc
@@ -78,6 +86,10 @@ function policy.policies()
             ["build.c++.gcc.modules.cxx11abi"]    = {description = "Force to enable new cxx11 abi in C++ modules for gcc.", type = "boolean"},
             -- Enable cuda device link
             ["build.cuda.devlink"]                = {description = "Enable Cuda devlink.", type = "boolean"},
+            -- Enable windows UAC and set level, e.g. invoker, admin, highest
+            ["windows.manifest.uac"]              = {description = "Enable windows manifest UAC.", type = "string"},
+            -- Enable ui access for windows UAC
+            ["windows.manifest.uac.ui"]           = {description = "Enable windows manifest UAC.", type = "boolean"},
             -- Automatically build before running
             ["run.autobuild"]                     = {description = "Automatically build before running.", type = "boolean"},
             -- Preprocessor configuration for ccache/distcc, we can disable linemarkers to speed up preprocess
@@ -96,6 +108,8 @@ function policy.policies()
             ["package.install_only"]              = {description = "Only install packages from remote.", type = "boolean"},
             -- Always install packages every time
             ["package.install_always"]            = {description = "Always install packages every time.", type = "boolean"},
+            -- Install packages in the local project folder
+            ["package.install_locally"]           = {description = "Install packages in the local project folder.", default = false, type = "boolean"},
             -- Set custom headers when downloading package
             ["package.download.http_headers"]     = {description = "Set the custom http headers when downloading package."},
             -- Use includes as external header files? e.g. -isystem ..
@@ -112,9 +126,18 @@ function policy.policies()
             ["package.librarydeps.strict_compatibility"] = {description = "Set strict compatibility for package and it's all library dependencies.", type = "boolean"},
             -- Automatically passes dependency configuration for inner xmake package
             -- https://github.com/xmake-io/xmake/issues/3952
-            ["package.xmake.pass_depconfs"] = {description = "Automatically passes dependency configuration for inner xmake package", default = true, type = "boolean"},
-            -- will force cmake package use ninja for build
-            ["package.cmake_generator.ninja"] = {description = "Set cmake package use ninja for build", default = false, type = "boolean"}
+            ["package.xmake.pass_depconfs"]       = {description = "Automatically passes dependency configuration for inner xmake package", default = true, type = "boolean"},
+            -- It will force cmake package use ninja for build
+            ["package.cmake_generator.ninja"]     = {description = "Set cmake package use ninja for build", default = false, type = "boolean"},
+            -- Stop to test on the first failure
+            ["test.stop_on_first_failure"]        = {description = "Stop to test on the first failure", default = false, type = "boolean"},
+            -- Return zero as exit code on failure
+            ["test.return_zero_on_failure"]       = {description = "Return zero as the exit code on failure", default = false, type = "boolean"},
+            -- Show diagnosis info for checking build dependencies
+            ["diagnosis.check_build_deps"]        = {description = "Show diagnosis info for checking build dependencies", default = false, type = "boolean"},
+            -- Set the network mode, e.g. public/private
+            --   private: it will disable fetch remote package repositories
+            ["network.mode"]                      = {description = "Set the network mode", type = "string"}
         }
         policy._POLICIES = policies
     end
